Ditest: Class Methods for Ditest Objects

DitestR Documentation

Class Methods for Ditest Objects

Description

Common functions to handle ⁠"Ditest"⁠ class results from the Dimodal feature tests.

Usage

## S3 method for class 'Ditest'
print(x, ...)
## S3 method for class 'Ditest'
summary(object, ...)

Arguments

x

an object of class ⁠"Ditest"⁠

object

an object of class ⁠"Ditest"⁠

...

extra arguments, ignored for all methods

Details

The values of the individual tests specify the contents of the object. These functions provide a common formatting of the result. The print methods show the test applied and all parameters, as well as the result. The summary methods show the tested statistic and the resulting probability.

Value

the argument x or object, invisible

See Also

Dipeak.test, Diflat.test, Dinrun.test, Dirunlen.test, Diexcurht.test, Dipermht.test

Examples

ptst <- Dipeak.test(1:4, 250, 0.15, 'bartlett')
ptst
## Summary results.
summary(ptst)

Dimodal documentation built on May 2, 2026, 1:06 a.m.