| Ditest | R Documentation |
Common functions to handle "Ditest" class results from the Dimodal
feature tests.
## S3 method for class 'Ditest'
print(x, ...)
## S3 method for class 'Ditest'
summary(object, ...)
x |
an object of class |
object |
an object of class |
... |
extra arguments, ignored for all methods |
The values of the individual tests specify the contents of the object. These functions provide a common formatting of the result. The print methods show the test applied and all parameters, as well as the result. The summary methods show the tested statistic and the resulting probability.
the argument x or object, invisible
Dipeak.test,
Diflat.test,
Dinrun.test,
Dirunlen.test,
Diexcurht.test,
Dipermht.test
ptst <- Dipeak.test(1:4, 250, 0.15, 'bartlett')
ptst
## Summary results.
summary(ptst)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.